@@ -4,11 +4,12 @@ import collections
 
 from .versions import _DICT_VERSION_ACCOUNT, _DICT_VERSION_STATUS, _DICT_VERSION_RELATIONSHIP, _DICT_VERSION_LIST, _DICT_VERSION_FAMILIAR_FOLLOWERS, _DICT_VERSION_HASHTAG
 from .defaults import _DEFAULT_SCOPES, _SCOPE_SETS
-from .errors import MastodonIllegalArgumentError, MastodonAPIError
+from .errors import MastodonIllegalArgumentError, MastodonAPIError, MastodonNotFoundError
 from .utility import api_version
 
 from .internals import Mastodon as Internals
 
+
 class Mastodon(Internals):
     @api_version("2.7.0", "2.7.0", "3.4.0")
     def create_account(self, username, password, email, agreement=False, reason=None, locale="en", scopes=_DEFAULT_SCOPES, to_file=None, return_detailed_error=False):
@@ -16,8 +17,8 @@ class Mastodon(Internals):
         Creates a new user account with the given username, password and email. "agreement"
         must be set to true (after showing the user the instance's user agreement and having
         them agree to it), "locale" specifies the language for the confirmation email as an
-        ISO 639-1 (two letter) or, if a language does not have one, 639-3 (three letter) language 
-        code. `reason` can be used to specify why a user would like to join if approved-registrations 
+        ISO 639-1 (two letter) or, if a language does not have one, 639-3 (three letter) language
+        code. `reason` can be used to specify why a user would like to join if approved-registrations
         mode is on.
 
         Does not require an access token, but does require a client grant.
@@ -30,11 +31,11 @@ class Mastodon(Internals):
 
         By default, the function will throw if the account could not be created. Alternately,
         when `return_detailed_error` is passed, Mastodon.py will return the detailed error
-        response that the API provides (Starting from version 3.4.0 - not checked here) as an dict with 
-        error details as the second return value and the token returned as `None` in case of error. 
-        The dict will contain a text `error` values as well as a `details` value which is a dict with 
-        one optional key for each potential field (`username`, `password`, `email` and `agreement`), 
-        each if present containing a dict with an `error` category and free text `description`. 
+        response that the API provides (Starting from version 3.4.0 - not checked here) as an dict with
+        error details as the second return value and the token returned as `None` in case of error.
+        The dict will contain a text `error` values as well as a `details` value which is a dict with
+        one optional key for each potential field (`username`, `password`, `email` and `agreement`),
+        each if present containing a dict with an `error` category and free text `description`.
         Valid error categories are:
 
             * ERR_BLOCKED - When e-mail provider is not allowed
@@ -66,7 +67,7 @@ class Mastodon(Internals):
             response = self.__api_request('POST', '/oauth/token', oauth_params, do_ratelimiting=False)
             temp_access_token = response['access_token']
         except Exception as e:
-            raise MastodonIllegalArgumentError('Invalid request during oauth phase: %s' % e)
+            raise MastodonIllegalArgumentError(f'Invalid request during oauth phase: {e}')
 
         # Step 2: Use that to create a user
         try:
@@ -74,10 +75,10 @@ class Mastodon(Internals):
             if "error" in response:
                 if return_detailed_error:
                     return None, response
-                raise MastodonIllegalArgumentError('Invalid request: %s' % e)
+                raise MastodonIllegalArgumentError(f'Invalid request: {e}')
             self.access_token = response['access_token']
             self.__set_refresh_token(response.get('refresh_token'))
-            self.__set_token_expired(int(response.get('expires_in', 0)))            
+            self.__set_token_expired(int(response.get('expires_in', 0)))
         except Exception as e:
             raise MastodonIllegalArgumentError('Invalid request')
 
@@ -88,7 +89,10 @@ class Mastodon(Internals):
                 received_scopes += _SCOPE_SETS[scope_set]
 
         if not set(scopes) <= set(received_scopes):
-            raise MastodonAPIError('Granted scopes "' + " ".join(received_scopes) + '" do not contain all of the requested scopes "' + " ".join(scopes) + '".')
+            raise MastodonAPIError(
+                f'Granted scopes "{" ".join(received_scopes)}" '
+                f'do not contain all of the requested scopes "{" ".join(scopes)}".'
+            )
 
         if to_file is not None:
             with open(to_file, 'w') as token_file:
@@ -124,8 +128,7 @@ class Mastodon(Internals):
         Returns a :ref:`account dict <account dict>`.
         """
         id = self.__unpack_id(id)
-        url = '/api/v1/accounts/{0}'.format(str(id))
-        return self.__api_request('GET', url)
+        return self.__api_request('GET', f'/api/v1/accounts/{id}')
 
     @api_version("1.0.0", "2.1.0", _DICT_VERSION_ACCOUNT)
     def account_verify_credentials(self):
@@ -140,7 +143,7 @@ class Mastodon(Internals):
     def me(self):
         """
         Get this user's account. Synonym for `account_verify_credentials()`, does exactly
-        the same thing, just exists becase `account_verify_credentials()` has a confusing
+        the same thing, just exists because `account_verify_credentials()` has a confusing
         name.
         """
         return self.account_verify_credentials()
@@ -185,8 +188,7 @@ class Mastodon(Internals):
         if not exclude_reblogs:
             del params["exclude_reblogs"]
 
-        url = '/api/v1/accounts/{0}/statuses'.format(str(id))
-        return self.__api_request('GET', url, params)
+        return self.__api_request('GET', f'/api/v1/accounts/{id}/statuses', params)
 
     @api_version("1.0.0", "2.6.0", _DICT_VERSION_ACCOUNT)
     def account_following(self, id, max_id=None, min_id=None, since_id=None, limit=None):
@@ -206,8 +208,7 @@ class Mastodon(Internals):
             since_id = self.__unpack_id(since_id, dateconv=True)
 
         params = self.__generate_params(locals(), ['id'])
-        url = '/api/v1/accounts/{0}/following'.format(str(id))
-        return self.__api_request('GET', url, params)
+        return self.__api_request('GET', f'/api/v1/accounts/{id}/following', params)
 
     @api_version("1.0.0", "2.6.0", _DICT_VERSION_ACCOUNT)
     def account_followers(self, id, max_id=None, min_id=None, since_id=None, limit=None):
@@ -227,8 +228,7 @@ class Mastodon(Internals):
             since_id = self.__unpack_id(since_id, dateconv=True)
 
         params = self.__generate_params(locals(), ['id'])
-        url = '/api/v1/accounts/{0}/followers'.format(str(id))
-        return self.__api_request('GET', url, params)
+        return self.__api_request('GET', f'/api/v1/accounts/{id}/followers', params)
 
     @api_version("1.0.0", "1.4.0", _DICT_VERSION_RELATIONSHIP)
     def account_relationships(self, id):
@@ -244,7 +244,7 @@ class Mastodon(Internals):
                                   params)
 
     @api_version("1.0.0", "2.3.0", _DICT_VERSION_ACCOUNT)
-    def account_search(self, q, limit=None, following=False):
+    def account_search(self, q, limit=None, following=False, resolve=False):
         """
         Fetch matching accounts. Will lookup an account remotely if the search term is
         in the username@domain format and not yet in the database. Set `following` to
@@ -269,21 +269,20 @@ class Mastodon(Internals):
         """
         id = self.__unpack_id(id)
         params = self.__generate_params(locals(), ['id'])
-        url = '/api/v1/accounts/{0}/lists'.format(str(id))
-        return self.__api_request('GET', url, params)
+        return self.__api_request('GET', f'/api/v1/accounts/{id}/lists', params)
 
     @api_version("3.4.0", "3.4.0", _DICT_VERSION_ACCOUNT)
     def account_lookup(self, acct):
         """
         Look up an account from user@instance form (@instance allowed but not required for
-        local accounts). Will only return accounts that the instance already knows about, 
-        and not do any webfinger requests. Use `account_search` if you need to resolve users 
+        local accounts). Will only return accounts that the instance already knows about,
+        and not do any webfinger requests. Use `account_search` if you need to resolve users
         through webfinger from remote.
 
         Returns an :ref:`account dict <account dict>`.
         """
         return self.__api_request('GET', '/api/v1/accounts/lookup', self.__generate_params(locals()))
-    
+
     @api_version("3.5.0", "3.5.0", _DICT_VERSION_FAMILIAR_FOLLOWERS)
     def account_familiar_followers(self, id):
         """
@@ -317,18 +316,22 @@ class Mastodon(Internals):
         if params["reblogs"] is None:
             del params["reblogs"]
 
-        url = '/api/v1/accounts/{0}/follow'.format(str(id))
-        return self.__api_request('POST', url, params)
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/follow', params)
 
     @api_version("1.0.0", "2.1.0", _DICT_VERSION_ACCOUNT)
     def follows(self, uri):
         """
-        Follow a remote user by uri (username@domain).
+        Follow a remote user with username given in username@domain form.
 
         Returns a :ref:`account dict <account dict>`.
+
+        Deprecated - avoid using this. Currently uses a backwards compat implementation that may or may not work properly.
         """
-        params = self.__generate_params(locals())
-        return self.__api_request('POST', '/api/v1/follows', params)
+        try:
+            acct = self.account_search(uri)[0]
+        except:
+            raise MastodonNotFoundError("User not found")
+        return self.account_follow(acct)
 
     @api_version("1.0.0", "1.4.0", _DICT_VERSION_RELATIONSHIP)
     def account_unfollow(self, id):
@@ -338,7 +341,7 @@ class Mastodon(Internals):
         Returns a :ref:`relationship dict <relationship dict>` containing the updated relationship to the user.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/accounts/{0}/unfollow'.format(str(id)))
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/unfollow')
 
     @api_version("3.5.0", "3.5.0", _DICT_VERSION_RELATIONSHIP)
     def account_remove_from_followers(self, id):
@@ -349,8 +352,7 @@ class Mastodon(Internals):
         Returns a :ref:`relationship dict <relationship dict>` reflecting the updated following status.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/accounts/{0}/remove_from_followers'.format(str(id)))
-    
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/remove_from_followers')
 
     @api_version("1.0.0", "1.4.0", _DICT_VERSION_RELATIONSHIP)
     def account_block(self, id):
@@ -360,8 +362,7 @@ class Mastodon(Internals):
         Returns a :ref:`relationship dict <relationship dict>` containing the updated relationship to the user.
         """
         id = self.__unpack_id(id)
-        url = '/api/v1/accounts/{0}/block'.format(str(id))
-        return self.__api_request('POST', url)
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/block')
 
     @api_version("1.0.0", "1.4.0", _DICT_VERSION_RELATIONSHIP)
     def account_unblock(self, id):
@@ -371,8 +372,7 @@ class Mastodon(Internals):
         Returns a :ref:`relationship dict <relationship dict>` containing the updated relationship to the user.
         """
         id = self.__unpack_id(id)
-        url = '/api/v1/accounts/{0}/unblock'.format(str(id))
-        return self.__api_request('POST', url)
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/unblock')
 
     @api_version("1.1.0", "2.4.3", _DICT_VERSION_RELATIONSHIP)
     def account_mute(self, id, notifications=True, duration=None):
@@ -387,8 +387,7 @@ class Mastodon(Internals):
         """
         id = self.__unpack_id(id)
         params = self.__generate_params(locals(), ['id'])
-        url = '/api/v1/accounts/{0}/mute'.format(str(id))
-        return self.__api_request('POST', url, params)
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/mute', params)
 
     @api_version("1.1.0", "1.4.0", _DICT_VERSION_RELATIONSHIP)
     def account_unmute(self, id):
@@ -398,8 +397,7 @@ class Mastodon(Internals):
         Returns a :ref:`relationship dict <relationship dict>` containing the updated relationship to the user.
         """
         id = self.__unpack_id(id)
-        url = '/api/v1/accounts/{0}/unmute'.format(str(id))
-        return self.__api_request('POST', url)
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/unmute')
 
     @api_version("1.1.1", "3.1.0", _DICT_VERSION_ACCOUNT)
     def account_update_credentials(self, display_name=None, note=None,
@@ -436,10 +434,8 @@ class Mastodon(Internals):
 
             fields_attributes = []
             for idx, (field_name, field_value) in enumerate(fields):
-                params_initial['fields_attributes[' +
-                               str(idx) + '][name]'] = field_name
-                params_initial['fields_attributes[' +
-                               str(idx) + '][value]'] = field_value
+                params_initial[f'fields_attributes[{idx}][name]'] = field_name
+                params_initial[f'fields_attributes[{idx}][value]'] = field_value
 
         # Clean up params
         for param in ["avatar", "avatar_mime_type", "header", "header_mime_type", "fields"]:
@@ -464,8 +460,7 @@ class Mastodon(Internals):
         Returns a :ref:`relationship dict <relationship dict>` containing the updated relationship to the user.
         """
         id = self.__unpack_id(id)
-        url = '/api/v1/accounts/{0}/pin'.format(str(id))
-        return self.__api_request('POST', url)
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/pin')
 
     @api_version("2.5.0", "2.5.0", _DICT_VERSION_RELATIONSHIP)
     def account_unpin(self, id):
@@ -475,8 +470,7 @@ class Mastodon(Internals):
         Returns a :ref:`relationship dict <relationship dict>` containing the updated relationship to the user.
         """
         id = self.__unpack_id(id)
-        url = '/api/v1/accounts/{0}/unpin'.format(str(id))
-        return self.__api_request('POST', url)
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/unpin')
 
     @api_version("3.2.0", "3.2.0", _DICT_VERSION_RELATIONSHIP)
     def account_note_set(self, id, comment):
@@ -487,7 +481,7 @@ class Mastodon(Internals):
         """
         id = self.__unpack_id(id)
         params = self.__generate_params(locals(), ["id"])
-        return self.__api_request('POST', '/api/v1/accounts/{0}/note'.format(str(id)), params)
+        return self.__api_request('POST', f'/api/v1/accounts/{id}/note', params)
 
     @api_version("3.3.0", "3.3.0", _DICT_VERSION_HASHTAG)
     def account_featured_tags(self, id):
@@ -497,4 +491,4 @@ class Mastodon(Internals):
         Returns a list of :ref:`hashtag dicts <hashtag dicts>` (NOT `featured tag dicts`_).
         """
         id = self.__unpack_id(id)
-        return self.__api_request('GET', '/api/v1/accounts/{0}/featured_tags'.format(str(id)))
+        return self.__api_request('GET', f'/api/v1/accounts/{id}/featured_tags')
