@@ -7,12 +7,13 @@ from .utility import api_version
 
 from .internals import Mastodon as Internals
 
+
 class Mastodon(Internals):
     ###
     # Moderation API
     ###
     @api_version("2.9.1", "4.0.0", _DICT_VERSION_ADMIN_ACCOUNT)
-    def admin_accounts_v2(self, origin=None, by_domain=None, status=None, username=None, display_name=None, email=None, ip=None, 
+    def admin_accounts_v2(self, origin=None, by_domain=None, status=None, username=None, display_name=None, email=None, ip=None,
                             permissions=None, invited_by=None, role_ids=None, max_id=None, min_id=None, since_id=None, limit=None):
         """
         Fetches a list of accounts that match given criteria. By default, local accounts are returned.
@@ -42,7 +43,7 @@ class Mastodon(Internals):
         if role_ids is not None:
             if not isinstance(role_ids, list):
                 role_ids = [role_ids]
-            role_ids = list(map(self.__unpack_id, role_ids))
+            role_ids = [self.__unpack_id(x) for x in role_ids]
 
         if invited_by is not None:
             invited_by = self.__unpack_id(invited_by)
@@ -65,8 +66,8 @@ class Mastodon(Internals):
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_ADMIN_ACCOUNT)
     def admin_accounts(self, remote=False, by_domain=None, status='active', username=None, display_name=None, email=None, ip=None, staff_only=False, max_id=None, min_id=None, since_id=None, limit=None):
         """
-        Currently a synonym for admin_accounts_v1, now deprecated. You are strongly encouraged to use admin_accounts_v2 instead, since this one is kind of bad. 
-        
+        Currently a synonym for admin_accounts_v1, now deprecated. You are strongly encouraged to use admin_accounts_v2 instead, since this one is kind of bad.
+
         !!!!! This function may be switched to calling the v2 API in the future. This is your warning. If you want to keep using v1, use it explicitly. !!!!!
         """
         return self.admin_accounts_v1(
@@ -142,7 +143,7 @@ class Mastodon(Internals):
         Returns that dict.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('GET', '/api/v1/admin/accounts/{0}'.format(id))
+        return self.__api_request('GET', f'/api/v1/admin/accounts/{id}')
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_ADMIN_ACCOUNT)
     def admin_account_enable(self, id):
@@ -152,7 +153,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`admin account dict <admin account dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/accounts/{0}/enable'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/accounts/{id}/enable')
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_ADMIN_ACCOUNT)
     def admin_account_approve(self, id):
@@ -162,7 +163,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`admin account dict <admin account dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/accounts/{0}/approve'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/accounts/{id}/approve')
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_ADMIN_ACCOUNT)
     def admin_account_reject(self, id):
@@ -172,7 +173,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`admin account dict <admin account dict>` for the account that is now gone.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/accounts/{0}/reject'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/accounts/{id}/reject')
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_ADMIN_ACCOUNT)
     def admin_account_unsilence(self, id):
@@ -182,7 +183,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`admin account dict <admin account dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/accounts/{0}/unsilence'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/accounts/{id}/unsilence')
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_ADMIN_ACCOUNT)
     def admin_account_unsuspend(self, id):
@@ -192,7 +193,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`admin account dict <admin account dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/accounts/{0}/unsuspend'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/accounts/{id}/unsuspend')
 
     @api_version("3.3.0", "3.3.0", _DICT_VERSION_ADMIN_ACCOUNT)
     def admin_account_delete(self, id):
@@ -202,7 +203,7 @@ class Mastodon(Internals):
         The deleted accounts :ref:`admin account dict <admin account dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('DELETE', '/api/v1/admin/accounts/{0}'.format(id))
+        return self.__api_request('DELETE', f'/api/v1/admin/accounts/{id}')
 
     @api_version("3.3.0", "3.3.0", _DICT_VERSION_ADMIN_ACCOUNT)
     def admin_account_unsensitive(self, id):
@@ -212,7 +213,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`admin account dict <admin account dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/accounts/{0}/unsensitive'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/accounts/{id}/unsensitive')
 
     @api_version("2.9.1", "2.9.1", "2.9.1")
     def admin_account_moderate(self, id, action=None, report_id=None, warning_preset_id=None, text=None, send_email_notification=True):
@@ -248,8 +249,7 @@ class Mastodon(Internals):
 
         params["type"] = action
 
-        self.__api_request(
-            'POST', '/api/v1/admin/accounts/{0}/action'.format(id), params)
+        self.__api_request('POST', f'/api/v1/admin/accounts/{id}/action', params)
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_REPORT)
     def admin_reports(self, resolved=False, account_id=None, target_account_id=None, max_id=None, min_id=None, since_id=None, limit=None):
@@ -290,7 +290,7 @@ class Mastodon(Internals):
         Returns a :ref:`report dict <report dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('GET', '/api/v1/admin/reports/{0}'.format(id))
+        return self.__api_request('GET', f'/api/v1/admin/reports/{id}')
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_REPORT)
     def admin_report_assign(self, id):
@@ -300,7 +300,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`report dict <report dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/reports/{0}/assign_to_self'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/reports/{id}/assign_to_self')
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_REPORT)
     def admin_report_unassign(self, id):
@@ -310,7 +310,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`report dict <report dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/reports/{0}/unassign'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/reports/{id}/unassign')
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_REPORT)
     def admin_report_reopen(self, id):
@@ -320,7 +320,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`report dict <report dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/reports/{0}/reopen'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/reports/{id}/reopen')
 
     @api_version("2.9.1", "2.9.1", _DICT_VERSION_REPORT)
     def admin_report_resolve(self, id):
@@ -330,7 +330,7 @@ class Mastodon(Internals):
         Returns the updated :ref:`report dict <report dict>`.
         """
         id = self.__unpack_id(id)
-        return self.__api_request('POST', '/api/v1/admin/reports/{0}/resolve'.format(id))
+        return self.__api_request('POST', f'/api/v1/admin/reports/{id}/resolve')
 
     @api_version("3.5.0", "3.5.0", _DICT_VERSION_HASHTAG)
     def admin_trending_tags(self, limit=None):
@@ -366,7 +366,7 @@ class Mastodon(Internals):
         return self.__api_request('GET', '/api/v1/admin/trends/links', params)
 
     @api_version("4.0.0", "4.0.0", _DICT_VERSION_ADMIN_DOMAIN_BLOCK)
-    def admin_domain_blocks(self, id=None, limit:int=None):
+    def admin_domain_blocks(self, id=None, max_id=None, min_id=None, since_id=None, limit=None):
         """
         Fetches a list of blocked domains. Requires scope `admin:read:domain_blocks`.
 
@@ -374,20 +374,29 @@ class Mastodon(Internals):
 
         Returns a list of :ref:`admin domain block dicts <admin domain block dicts>`, raises a `MastodonAPIError` if the specified block does not exist.
         """
+        if max_id is not None:
+            max_id = self.__unpack_id(max_id)
+
+        if min_id is not None:
+            min_id = self.__unpack_id(min_id)
+
+        if since_id is not None:
+            since_id = self.__unpack_id(since_id)
+
         if id is not None:
             id = self.__unpack_id(id)
-            return self.__api_request('GET', '/api/v1/admin/domain_blocks/{0}'.format(id))
+            return self.__api_request('GET', f'/api/v1/admin/domain_blocks/{id}')
         else:
-            params = self.__generate_params(locals(),['limit'])
+            params = self.__generate_params(locals(), ['limit'])
             return self.__api_request('GET', '/api/v1/admin/domain_blocks/', params)
-    
+
     @api_version("4.0.0", "4.0.0", _DICT_VERSION_ADMIN_DOMAIN_BLOCK)
     def admin_create_domain_block(self, domain:str, severity:str=None, reject_media:bool=None, reject_reports:bool=None, private_comment:str=None, public_comment:str=None, obfuscate:bool=None):
         """
         Perform a moderation action on a domain. Requires scope `admin:write:domain_blocks`.
 
         Valid severities are:
-            * "silence" - hide all posts from federated timelines and do not show notifications to local users from the remote instance's users unless they are following the remote user. 
+            * "silence" - hide all posts from federated timelines and do not show notifications to local users from the remote instance's users unless they are following the remote user.
             * "suspend" - deny interactions with this instance going forward. This action is reversible.
             * "limit" - generally used with reject_media=true to force reject media from an instance without silencing or suspending..
 
@@ -412,7 +421,7 @@ class Mastodon(Internals):
         Modify existing moderation action on a domain. Requires scope `admin:write:domain_blocks`.
 
         Valid severities are:
-            * "silence" - hide all posts from federated timelines and do not show notifications to local users from the remote instance's users unless they are following the remote user. 
+            * "silence" - hide all posts from federated timelines and do not show notifications to local users from the remote instance's users unless they are following the remote user.
             * "suspend" - deny interactions with this instance going forward. This action is reversible.
             * "limit" - generally used with reject_media=true to force reject media from an instance without silencing or suspending.
 
@@ -430,7 +439,7 @@ class Mastodon(Internals):
             raise AttributeError("Must provide an id to modify the existing moderation actions on a given domain.")
         id = self.__unpack_id(id)
         params = self.__generate_params(locals(), ["id"])
-        return self.__api_request('PUT', '/api/v1/admin/domain_blocks/{0}'.format(id), params)
+        return self.__api_request('PUT', f'/api/v1/admin/domain_blocks/{id}', params)
 
     @api_version("4.0.0", "4.0.0", _DICT_VERSION_ADMIN_DOMAIN_BLOCK)
     def admin_delete_domain_block(self, id=None):
@@ -443,7 +452,7 @@ class Mastodon(Internals):
         """
         if id is not None:
             id = self.__unpack_id(id)
-            self.__api_request('DELETE', '/api/v1/admin/domain_blocks/{0}'.format(id))
+            self.__api_request('DELETE', f'/api/v1/admin/domain_blocks/{id}')
         else:
             raise AttributeError("You must provide an id of an existing domain block to remove it.")
 
@@ -482,7 +491,7 @@ class Mastodon(Internals):
         for key in ["active_users", "new_users", "interactions", "opened_reports", "resolved_reports"]:
             if params_init[key] == True:
                 keys.append(key)
-        
+
         params = {}
         for key in ["tag_accounts", "tag_uses", "tag_servers"]:
             if params_init[key] is not None:
@@ -499,7 +508,7 @@ class Mastodon(Internals):
         params["keys"] = keys
         params["start_at"] = self.__consistent_isoformat_utc(start_at)
         params["end_at"] = self.__consistent_isoformat_utc(end_at)
-        
+
         return self.__api_request('POST', '/api/v1/admin/measures', params, use_json=True)
 
     @api_version("3.5.0", "3.5.0", _DICT_VERSION_ADMIN_DIMENSION)
@@ -532,7 +541,7 @@ class Mastodon(Internals):
         for key in ["languages", "sources", "servers", "space_usage", "software_versions"]:
             if params_init[key] == True:
                 keys.append(key)
-        
+
         params = {}
         for key in ["tag_servers", "tag_languages"]:
             if params_init[key] is not None:
@@ -551,7 +560,7 @@ class Mastodon(Internals):
             params["limit"] = limit
         params["start_at"] = self.__consistent_isoformat_utc(start_at)
         params["end_at"] = self.__consistent_isoformat_utc(end_at)
-        
+
         return self.__api_request('POST', '/api/v1/admin/dimensions', params, use_json=True)
 
     @api_version("3.5.0", "3.5.0", _DICT_VERSION_ADMIN_RETENTION)
@@ -569,4 +578,4 @@ class Mastodon(Internals):
             "end_at": self.__consistent_isoformat_utc(end_at),
             "frequency": frequency
         }
-        return self.__api_request('POST', '/api/v1/admin/retention', params)
\ No newline at end of file
+        return self.__api_request('POST', '/api/v1/admin/retention', params)
