@@ -5,7 +5,8 @@ from .utility import api_version
 
 from .internals import Mastodon as Internals
 
-class Mastodon(Internals):    
+
+class Mastodon(Internals):
     ###
     # Reading data: Conversations
     ###
@@ -39,5 +40,4 @@ class Mastodon(Internals):
         Returns the updated :ref:`conversation dict <conversation dict>`.
         """
         id = self.__unpack_id(id)
-        url = '/api/v1/conversations/{0}/read'.format(str(id))
-        return self.__api_request('POST', url)
+        return self.__api_request('POST', f'/api/v1/conversations/{id}/read')
