@@ -12,7 +12,7 @@ except:
 
 from mastodon import Mastodon
 from mastodon.Mastodon import MastodonMalformedEventError, MastodonNetworkError, MastodonReadTimeout
-from requests.exceptions import ChunkedEncodingError, ReadTimeout
+from requests.exceptions import ChunkedEncodingError, ReadTimeout, ConnectionError
 
 
 class StreamListener(object):
@@ -84,7 +84,7 @@ class StreamListener(object):
         contains the content of the unknown event.
         """
         pass
-    
+
     def handle_heartbeat(self):
         """The server has sent us a keep-alive message. This callback may be
         useful to carry out periodic housekeeping tasks, or just to confirm
@@ -136,7 +136,7 @@ class StreamListener(object):
                 exception,
                 err
             )
-        except MastodonReadTimeout as err:
+        except ReadTimeout as err:
             exception = MastodonReadTimeout(
                 "Timed out while reading from server."),
             self.on_abort(exception)
@@ -144,6 +144,14 @@ class StreamListener(object):
                 exception,
                 err
             )
+        except ConnectionError as err:
+            exception = MastodonNetworkError(
+                "Requests reports connection error."),
+            self.on_abort(exception)
+            six.raise_from(
+                exception,
+                err
+            )
 
     def _parse_line(self, line, event):
         if line.startswith(':'):
@@ -217,6 +225,7 @@ class StreamListener(object):
             else:
                 handler(name, payload)
 
+
 class CallbackStreamListener(StreamListener):
     """
     Simple callback stream handler class.
@@ -226,21 +235,20 @@ class CallbackStreamListener(StreamListener):
     for diagnostics.
     """
 
-    def __init__(self, 
-        update_handler=None, 
-        local_update_handler=None, 
-        delete_handler=None, 
-        notification_handler=None, 
-        conversation_handler=None, 
-        unknown_event_handler=None, 
-        status_update_handler=None,
-        filters_changed_handler=None,
-        announcement_handler=None,
-        announcement_reaction_handler=None,
-        announcement_delete_handler=None,
-        encryted_message_handler=None
-
-    ):
+    def __init__(self,
+                 update_handler=None,
+                 local_update_handler=None,
+                 delete_handler=None,
+                 notification_handler=None,
+                 conversation_handler=None,
+                 unknown_event_handler=None,
+                 status_update_handler=None,
+                 filters_changed_handler=None,
+                 announcement_handler=None,
+                 announcement_reaction_handler=None,
+                 announcement_delete_handler=None,
+                 encryted_message_handler=None
+                 ):
         super(CallbackStreamListener, self).__init__()
         self.update_handler = update_handler
         self.local_update_handler = local_update_handler
@@ -306,4 +314,4 @@ class CallbackStreamListener(StreamListener):
 
     def on_unknown_event(self, name, unknown_event=None):
         if self.unknown_event_handler is not None:
-            self.unknown_event_handler(name, unknown_event)        
\ No newline at end of file
+            self.unknown_event_handler(name, unknown_event)
